@@ -1,7 +1,7 @@
 from .connection import Connection
 from .exceptions import PyQ3SLError, PyQ3SLTimeoutError
 from .principalserver import PrincipalServer
-from .server import Server
+from .server import Server, MedalOfHonorServer
 
 """
 pyq3serverlist.
@@ -9,7 +9,7 @@ pyq3serverlist.
 Simple Python library for querying Quake 3 based principal servers and their game servers.
 """
 
-__version__ = '0.1.9'
+__version__ = '0.2.0'
 __author__ = 'cetteup'
 __credits__ = 'https://github.com/jacklul'
-__all__ = ['Connection', 'PrincipalServer', 'Server', 'PyQ3SLError', 'PyQ3SLTimeoutError']
+__all__ = ['Connection', 'PrincipalServer', 'Server', 'MedalOfHonorServer',  'PyQ3SLError', 'PyQ3SLTimeoutError']
